<?php
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * @since Industri 1.0
 */
add_action( 'after_setup_theme', 'industri_setup' );

function industri_setup() { 

    // Add support for Block Styles.
    add_theme_support( 'wp-block-styles' );

    //  for translation
    load_theme_textdomain( 'industri' );

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );

    /*
     * Let WordPress manage the document title.
     * This theme does not use a hard-coded <title> tag in the document head,
     * WordPress will provide it for us.
     */
    add_theme_support( 'title-tag' );

    /**
     * Add post-formats support.
     */
    add_theme_support(
        'post-formats',
        array(              
            'video',
            'audio',            
        )
    );

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
     */
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size( 1568, 9999 );      

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    $html5_arg = array(
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
        'style',
        'script',
        'navigation-widgets',
    );
    add_theme_support('html5',$html5_arg);      

    // custom logo
    $logo_arg = array(
        'height'               => 100,
        'width'                => 300,
        'flex-width'           => true,
        'flex-height'          => true,
        'unlink-homepage-logo' => true,
    );

    add_theme_support('custom-logo',$logo_arg);

    // Custom header.
    add_theme_support( 'custom-header');

    // Custom background color.
    add_theme_support('custom-background',
        array(
            'default-color' => '#ffffff',
            'default-image'          => '',
            'default-repeat'         => 'repeat',
            'default-position-x'     => 'left',
            'default-position-y'     => 'top',
            'default-size'           => 'auto',
            'default-attachment'     => '',
            'wp-head-callback'       => '_custom_background_cb',
            'admin-head-callback'    => '',
            'admin-preview-callback' => ''
        )
    );

    add_theme_support( "responsive-embeds" );

    // Add theme support for selective refresh for widgets.
    add_theme_support( 'customize-selective-refresh-widgets' );   

    // Add support for full and wide align images.
    add_theme_support( 'align-wide' );   

    // menu
    register_nav_menus(
        array(
            'primary' => esc_html__( 'Primary Menu', 'industri' )               
        )
    );


      //WooCommerce Plugin Support

    add_theme_support( 'woocommerce' );

    // editor style
    add_editor_style( array( 'assets/css/editor-style.css', industri_fonts_url() ) );

    // content width
    $GLOBALS['content_width'] = apply_filters( 'industri_content_width', 1200 );

}



add_action( 'after_setup_theme', 'jetpack_support' );
function jetpack_support(){

    if ( defined( 'JETPACK__VERSION' ) ) {

        //  Add theme support for Responsive Videos.
        add_theme_support( 'jetpack-responsive-videos' );

            // Add theme support for Infinite Scroll.
        add_theme_support( 'infinite-scroll', array(
            'container' => 'content',
            'render'    => 'industri_components_infinite_scroll_render',
            'footer' => 'page',
        ) );

        // Add theme support for Social Menus
        add_theme_support( 'jetpack-social-menu' );

    }
}

// jetpack
function industri_components_infinite_scroll_render() {

    while ( have_posts() ) {
        the_post(); 
        if ( is_search() ) :        
            get_template_part( 'template-part/content', 'search' );
        else :
            get_template_part( 'template-parts/content', get_post_format() );
        endif;

    }
}


